Brand resources
===============

StoryPy logo
------------

The StoryPy logo is available in PNG and Photoshop formats.

Download links: `PNG <_static/logo.png>`__ `PSD <_static/logo.psd>`__

Legal
^^^^^

The StoryPy logo is the exclusive property of Andras Baki and the StoryPy project. Unauthorized use, reproduction, distribution, or modification of the StoryPy logo without prior written permission from StoryPy is strictly prohibited.

For permission, contact `andrasbaki6+storypy@googlemail.com <mailto:andrasbaki6+storypy@googlemail.com>`__.

Copyright (c) The StoryPy logo 2026 Andras Baki

